@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2004 Danilo Segan <danilo@kvota.net>.
+# Copyright (c) 2004, 2005, 2006 Danilo Segan <danilo@gnome.org>.
 #
 # This file is part of xml2po.
 #
@@ -36,8 +36,12 @@
 import re
 import libxml2
 import os
-import md5
 import sys
+try:
+    # Hashlib is new in Python 2.5
+    from hashlib import md5 as md5_new
+except ImportError:
+    from md5 import new as md5_new
 
 class docbookXmlMode:
     """Class for special handling of DocBook document types.
@@ -49,7 +53,7 @@ class docbookXmlMode:
                       'segmentedlist', 'simplelist', 'calloutlist', 'varlistentry' ]
         self.objects = [ 'figure', 'textobject', 'imageobject', 'mediaobject',
                          'screenshot' ]
-        
+
     def getIgnoredTags(self):
         "Returns array of tags to be ignored."
         return  self.objects + self.lists
@@ -73,6 +77,10 @@ class docbookXmlMode:
             'userinput'
             ]
 
+    def getTreatedAttributes(self):
+        "Returns array of tag attributes which content is to be translated"
+        return []
+
     def getStringForTranslators(self):
         """Returns string which will be used to credit translators."""
         return "translator-credits"
@@ -105,7 +113,7 @@ class docbookXmlMode:
         return last
 
     def _md5_for_file(self, filename):
-        hash = md5.new()
+        hash = md5_new()
         input = open(filename, "rb")
         read = input.read(4096)
         while read:
