@@ -507,7 +507,7 @@ def processElementTag(node, replacements, restart = 0):
         if mode == 'merge':
             translation = getTranslation(outtxt, isSpacePreserveNode(node))
         else:
-            translation = outtxt
+            translation = outtxt.decode('utf-8')
 
         starttag = startTagForNode(node)
         endtag = endTagForNode(node)
@@ -812,9 +812,9 @@ if mode=='merge' and mofile=='':
 
 if mofile:
     try:
-        file = open(mofile, "rb")
+        mfile = open(mofile, "rb")
 
-        gt = gettext.GNUTranslations(file)
+        gt = gettext.GNUTranslations(mfile)
         gt.add_fallback(NoneTranslations())
     except:
         print >> sys.stderr, "Can't open MO file '%s'." % (mofile)
